'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');

const useTypewriter = (text, speed = 100, onComplete) => {
    const [displayText, setDisplayText] = react.useState('');
    react.useEffect(() => {
        let i = 0;
        const typingInterval = setInterval(() => {
            setDisplayText(text.substring(0, i + 1));
            i++;
            if (i === text.length) {
                clearInterval(typingInterval);
                if (onComplete) {
                    onComplete();
                }
            }
        }, speed);
        return () => {
            clearInterval(typingInterval);
        };
    }, [text, speed, onComplete]);
    return displayText;
};

const Typewriter = ({ text, speed, onComplete }) => {
    const displayText = useTypewriter(text, speed, onComplete);
    return jsxRuntime.jsx("span", { children: displayText });
};

const AccordionItem = ({ bgColor, textColor, handleToggle, active, data, sendIcon }) => {
    const contentEl = react.useRef(null);
    const { label, contact } = data;
    const baseStyle = {
        backgroundColor: "white",
        boxShadow: "0 2px 4px rgba(0, 0, 0, 0.1)",
    };
    const activeStyle = active === label
        ? {
            marginBottom: "15px",
            borderRadius: "8px",
            color: "white",
        }
        : {
            marginBottom: "0px",
        };
    return (jsxRuntime.jsxs("div", { className: "rc-accordion-card", style: {
            ...baseStyle,
            ...activeStyle,
        }, children: [jsxRuntime.jsxs("header", { className: active === label ? "active" : "", style: active === label ? { backgroundColor: bgColor, color: "white" } : {
                    backgroundColor: "white",
                    color: textColor
                }, onClick: () => handleToggle(label), children: [jsxRuntime.jsx("h2", { children: label }), jsxRuntime.jsx("span", { children: "\u25B2" })] }), jsxRuntime.jsx("div", { ref: contentEl, className: `collapse ${active === label ? "show" : ""}`, style: active === label
                    ? { height: contentEl.current?.scrollHeight }
                    : { height: "0px" }, children: contact.map((person, index) => (jsxRuntime.jsx("div", { style: {
                        width: "100%",
                        display: "flex",
                    }, children: jsxRuntime.jsx("a", { href: `https://wa.me/${person.number}`, target: "_blank", rel: "noreferrer", style: {
                            display: "flex",
                            justifyContent: "space-between",
                            alignItems: "center",
                        }, children: jsxRuntime.jsxs("p", { children: [person.name, jsxRuntime.jsx("span", { children: sendIcon })] }) }) }, index))) })] }));
};
const Accordion = ({ dataList = [], sendIcon = jsxRuntime.jsx("span", { children: "\u25B6" }), bgColor = "#0E5BF0", textColor = "#0E5BF0", }) => {
    const [active, setActive] = react.useState(null);
    const handleToggle = (label) => {
        setActive(active === label ? null : label);
    };
    return (jsxRuntime.jsx("article", { children: dataList.map((item) => (jsxRuntime.jsx(AccordionItem, { bgColor: bgColor, textColor: textColor, sendIcon: sendIcon, active: active, handleToggle: handleToggle, data: item }, item.label))) }));
};

const WhatsappFloatingButton = ({ buttonText = 'Chat', buttonIcon = null, sendIcon = null, title = 'Chat with us', buttonPosition = { bottom: 16, right: 16 }, paperBackgroundColor = '#ffffff', buttonBackgroundColor = '#0E5BF0', buttonColor = '#0E5BF0', paperBorderRadius = '12px', buttonSize = 56, dataList, textsChat = ["How we can help you?", "Give me a question"], speedTyping = 100, }) => {
    const [isPaperOpen, setIsPaperOpen] = react.useState(false);
    const [currentTextIndex, setCurrentTextIndex] = react.useState(0);
    const handleComplete = () => {
        setTimeout(() => {
            setCurrentTextIndex((prevIndex) => (prevIndex + 1) % textsChat.length);
        }, 2000);
    };
    const togglePaper = () => {
        setIsPaperOpen(!isPaperOpen);
    };
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("button", { onClick: togglePaper, style: {
                    position: 'fixed',
                    bottom: buttonPosition.bottom,
                    right: buttonPosition.right,
                    backgroundColor: buttonBackgroundColor,
                    color: buttonColor,
                    borderRadius: '50%',
                    width: `${buttonSize}px`,
                    height: `${buttonSize}px`,
                    border: 'none',
                    cursor: 'pointer',
                    boxShadow: '0px 4px 12px rgba(0, 0, 0, 0.1)',
                    display: 'flex',
                    alignItems: 'center',
                    justifyContent: 'center',
                    fontSize: '24px',
                    lineHeight: 0,
                    padding: 0,
                }, children: buttonIcon || buttonText.charAt(0) }), isPaperOpen && (jsxRuntime.jsxs("div", { style: {
                    position: 'fixed',
                    bottom: buttonPosition.bottom + buttonSize + 16,
                    right: buttonPosition.right,
                    backgroundColor: paperBackgroundColor,
                    borderRadius: paperBorderRadius,
                    boxShadow: '0px 4px 20px rgba(0, 0, 0, 0.15)',
                    width: '350px',
                    maxWidth: '90vw',
                    zIndex: 1000,
                }, children: [jsxRuntime.jsxs("div", { style: {
                            backgroundColor: buttonBackgroundColor,
                            color: 'inherit',
                            padding: '10px 16px',
                            borderTopLeftRadius: paperBorderRadius,
                            borderTopRightRadius: paperBorderRadius,
                            display: 'flex',
                            fontWeight: 'normal',
                            whiteSpace: 'nowrap',
                            fontSize: '1.5rem',
                            justifyContent: 'space-between',
                            alignItems: 'center',
                        }, children: [jsxRuntime.jsx("span", { children: title }), jsxRuntime.jsx("button", { onClick: togglePaper, style: {
                                    background: 'none',
                                    border: 'none',
                                    color: '#ffffff',
                                    padding: '0',
                                    fontSize: '2rem',
                                    cursor: 'pointer',
                                }, children: "\u00D7" })] }), jsxRuntime.jsxs("div", { style: { padding: '16px' }, children: [jsxRuntime.jsx("div", { style: {
                                    width: '100%',
                                    fontSize: '16px',
                                    marginBottom: '42px',
                                    borderRadius: '6px',
                                    border: '1px solid #ddd',
                                    minHeight: '40px',
                                    backgroundColor: '#fff',
                                    boxShadow: '0 2px 4px rgba(0, 0, 0, 0.1)',
                                    fontWeight: 500,
                                    color: buttonBackgroundColor,
                                    display: 'flex',
                                    alignItems: 'center',
                                }, children: jsxRuntime.jsx("div", { className: "typewriter", style: { padding: '8px' }, children: jsxRuntime.jsx(Typewriter, { text: textsChat[currentTextIndex], onComplete: handleComplete, speed: speedTyping }) }) }), jsxRuntime.jsx(Accordion, { bgColor: buttonBackgroundColor, textColor: buttonBackgroundColor, dataList: dataList, sendIcon: sendIcon })] })] }))] }));
};

module.exports = WhatsappFloatingButton;
//# sourceMappingURL=index.js.map
